@@ -1,6 +1,7 @@
 <?php
 
-require_once dirname(__DIR__).'/vendor/autoload.php';
+$autoloader = require_once dirname(__DIR__).'/vendor/autoload.php';
+$autoloader->add('Swift_', __DIR__.'/unit');
 
 set_include_path(get_include_path().PATH_SEPARATOR.dirname(__DIR__).'/lib');
 
