@@ -714,7 +714,7 @@ class Swift_Transport_LoadBalancedTransportTest extends \SwiftMailerTestCase
     }
 
     /**
-     * Adapted from Yay_Matchers_ReferenceMatcher
+     * Adapted from Yay_Matchers_ReferenceMatcher.
      */
     public function varsAreReferences(&$ref1, &$ref2)
     {
@@ -748,9 +748,4 @@ class Swift_Transport_LoadBalancedTransportTest extends \SwiftMailerTestCase
     {
         return $this->getMockery('Swift_Events_EventListener');
     }
-
-    private function _createInnerTransport()
-    {
-        return $this->getMockery('Swift_Transport');
-    }
 }
